contexttools.Context
====================

.. inheritance-diagram:: abjad.tools.contexttools.Context.Context.Context
   :private-bases:

.. autoclass:: abjad.tools.contexttools.Context.Context.Context

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.contents_duration

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.duration_in_seconds

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.engraver_consists

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.engraver_removals

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.is_semantic

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.leaves

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.lilypond_format

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.music

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.override

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.parent

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.preprolated_duration

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.prolated_duration

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.prolation

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.set

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.spanners

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.start_offset

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.start_offset_in_seconds

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.stop_offset

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.stop_offset_in_seconds

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.context_name

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.is_nonsemantic

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.is_parallel

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.contexttools.Context.Context.Context.name

Methods
-------

.. automethod:: abjad.tools.contexttools.Context.Context.Context.append

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.extend

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.index

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.insert

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.pop

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.remove

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

Special Methods
---------------

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__add__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__contains__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__delitem__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__getitem__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__iadd__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__imul__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__len__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__mul__

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__radd__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__repr__

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__rmul__

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.contexttools.Context.Context.Context.__setitem__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`
